@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.60 2003/05/19 11:08:13 gman Exp $ */
+/* $Id: gdict-app.c,v 1.64 2004/02/24 00:42:22 gman Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -64,19 +64,12 @@ dict_context_t *context;
 
 static void gdict_edit_menu_set_sensitivity (gboolean flag);
 
-static gint
-socket_dialog_close_cb (GtkWidget *widget, gpointer data) 
-{
-    socket_error_dialog = NULL;
-    return FALSE;
-}
-
 static void
 socket_error_cb (GtkWidget *widget, gchar *message, gpointer data) 
 {
     socket_error_dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                   		  GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                  		  "%s", message, NULL); 
+                                  		  "%s", message); 
     gtk_dialog_run (GTK_DIALOG (socket_error_dialog));
     gtk_widget_destroy (socket_error_dialog);
     
@@ -153,8 +146,11 @@ void
 gdict_open_speller (void) 
 {
     if (!speller) {
-        speller = GDICT_SPELLER (gdict_speller_new (context));
-        
+        speller = GDICT_SPELLER (gdict_speller_new ());
+
+	speller->context = context;
+	gdict_speller_reset_strat (speller);
+
         if (!speller) return;
 
         gtk_signal_connect (GTK_OBJECT (speller), "word_lookup_start",
@@ -212,7 +208,7 @@ gdict_app_do_lookup (gchar *text)
     word_entry_text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
     if ((word_entry_text == NULL) || (*word_entry_text == 0) || (strcmp (word_entry_text, text) != 0))
     {
-        g_strdown (text);
+        g_utf8_strdown (text, strlen (text));
         gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
         gtk_entry_set_text (GTK_ENTRY (word_entry), text);
     }
@@ -236,7 +232,7 @@ static void
 lookup_entry (void) 
 {
     gchar *text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
-    g_strdown(text);
+    g_utf8_strdown(text, strlen (text));
     gdict_app_do_lookup (text);
     if (text)
         g_free (text);
@@ -250,7 +246,7 @@ lookup_defbox (void)
     gtk_entry_set_text (GTK_ENTRY (word_entry), "");
     gtk_signal_emit_by_name (GTK_OBJECT (word_entry), "paste_clipboard");
     text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
-    g_strdown (text);
+    g_utf8_strdown (text, strlen (text));
     gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
     gdict_app_do_lookup (text);
     if (text)
@@ -327,7 +323,7 @@ lookup_button_drag_cb (GtkWidget *widget, GdkDragContext *context, gint x, gint
 	text = gtk_selection_data_get_text (sd);
 	
 	if (text) {
-		g_strdown (text);
+		g_utf8_strdown (text, strlen (text));
 		gtk_entry_set_text (GTK_ENTRY (word_entry), text);
     		gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
     		gdict_app_do_lookup (text);
@@ -478,7 +474,7 @@ find_cb (GtkMenuItem *menuitem, gpointer user_data)
 					  NULL);
     	hbox = gtk_hbox_new (FALSE, 8);
 	
-    	label = gtk_label_new_with_mnemonic ("_Search for:");
+    	label = gtk_label_new_with_mnemonic (_("_Search for:"));
     
     	entry = gtk_entry_new ();
    	gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
@@ -527,14 +523,6 @@ find_again_cb (GtkMenuItem *menuitem, gpointer user_data)
 	find_cb (NULL, NULL);
 }
 
-static void
-pref_dialog_apply_cb (GtkWidget *widget, gpointer user_data) 
-{
-    gdict_defbox_reset (defbox, context);
-    if (speller) 
-	gdict_speller_reset (speller, context);
-}
-
 void
 gdict_not_online () 
 {
@@ -546,7 +534,7 @@ gdict_not_online ()
     		           "or you are not connected to the Internet."));
     w = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                     "%s", s, NULL); 
+                                     "%s", s); 
     gtk_dialog_run (GTK_DIALOG (w));
     gtk_widget_destroy (w);
     g_free (s);
@@ -772,9 +760,8 @@ GtkWidget *gdict_app_create (gboolean applet) {
     GtkWidget *vbox;
     GtkWidget *hbox;
     GtkWidget *button;
-    GtkWidget *label, *word_label;
+    GtkWidget *word_label;
     GtkWidget *scrolled;
-    GtkWidget *defbox_vscrollbar;
     GtkTooltips *tooltips;
     static GtkTargetEntry drop_targets [] = {
     	{ "UTF8_STRING", 0, 0 },
@@ -804,12 +791,12 @@ GtkWidget *gdict_app_create (gboolean applet) {
     gtk_widget_show (vbox);
     gnome_app_set_contents (GNOME_APP (gdict_app), vbox);
     
-    hbox = gtk_hbox_new (FALSE, 6);
+    hbox = gtk_hbox_new (FALSE, 12);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
     gtk_widget_show (hbox);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    word_label = gtk_label_new_with_mnemonic (_("_Word: "));
+    word_label = gtk_label_new_with_mnemonic (_("_Word:"));
     gtk_widget_show ( GTK_WIDGET(word_label) );
     gtk_box_pack_start (GTK_BOX (hbox), word_label, FALSE, FALSE, 0);
     
@@ -849,7 +836,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
                                         GTK_POLICY_AUTOMATIC,             
 	       				GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_ETCHED_IN);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_NONE);
 
     gtk_widget_show (scrolled);
   
