@@ -1,7 +1,7 @@
 #ifndef __GDICT_APP_H_
 #define __GDICT_APP_H_
 
-/* $Id: gdict-app.h,v 1.12 2002/03/21 03:33:47 kevinv Exp $ */
+/* $Id: gdict-app.h,v 1.14 2002/05/10 12:58:01 gman Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -50,5 +50,7 @@ void gdict_not_online (void);
 GtkWidget *gdict_app_create (gboolean applet);
 void add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc);
 void add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType type);
+GtkWidget* gdict_button_new_with_stock_image (const gchar* text, const gchar* stock_id);
+GtkWidget* gdict_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stock_id, gint response_id);
 
 #endif /* __GDICT_APP_H_ */
