@@ -1,4 +1,4 @@
-/* $Id: gdict-defbox.c,v 1.21 2003/05/31 06:03:27 dcransto Exp $ */
+/* $Id: gdict-defbox.c,v 1.22 2004/04/27 05:23:04 gman Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -480,7 +480,6 @@ insert_text_with_tags (GtkTextBuffer *buffer, GtkTextIter *iter, gchar *p, gint
 		gtk_text_buffer_apply_tag_by_name (buffer, "italic", &start, iter);
 	if (underline)
 		gtk_text_buffer_apply_tag_by_name (buffer, "underline", &start, iter);
-			       
 }
 
 /* defbox_add
@@ -492,11 +491,12 @@ static void
 defbox_add (GDictDefbox *defbox, gchar *def) {
     GtkTextBuffer *buffer;
     GtkTextIter iter;
-    gchar *p;
+    gchar *p, *q;
     gint len;
     GdkFont *font;
     GdkColor *color;
     gboolean italic, bold, underline;
+    int length = 0;
 
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (defbox));
     gtk_text_buffer_get_end_iter (buffer, &iter);
@@ -581,8 +581,19 @@ defbox_add (GDictDefbox *defbox, gchar *def) {
             bold = FALSE;
             italic = TRUE;
             underline = FALSE;
-            ++p;
-        } else if ((*p == ']') || (*p == '}')) {
+			q = p;
+			while (*q != '}')
+			{
+				 length++;
+				 q++;
+                        }				
+			len = length;
+			
+			insert_text_with_tags (buffer, &iter, ++p, len-1, bold, italic, underline);
+			
+			p += length;
+			length = 0;
+        } else if (*p == ']' ) {
             font = gdict_pref.typefaces[TYPEFACE_BODY].font;
             color = gdict_pref.typefaces[TYPEFACE_BODY].color;
             bold = FALSE;
