@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.39 2003/10/19 06:41:23 kmaraas Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.40 2004/02/09 08:37:23 pborelli Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -8,7 +8,7 @@
  *  This code released under the GNU GPL.
  *  Read the file COPYING for more information.
  *
- *  GDict main window
+ *  GDict preferences window
  *
  */
 
@@ -27,25 +27,9 @@
 #include "gdict-pref-dialog.h"
 #include "gdict-app.h"
 
-enum {
-    APPLY_CHANGES_SIGNAL,
-    SOCKET_ERROR_SIGNAL,
-    LAST_SIGNAL
-};
-
-#define NUM_TYPEFACE_ROWS 4
-#define NUM_TYPEFACE_COLS 2
-
-GtkWidget *db_label, *strat_label;
-GtkWidget *error_label1 = NULL;
-GtkWidget *error_label2 = NULL;
-GtkWidget *alignment1 = NULL;
-GtkWidget *alignment2 = NULL;
-
-static gint gdict_pref_dialog_signals[LAST_SIGNAL] = { 0 };
-
-static void gdict_pref_dialog_init (GDictPrefDialog *pref_dialog);
 static void gdict_pref_dialog_class_init (GDictPrefDialogClass *class);
+static void gdict_pref_dialog_init (GDictPrefDialog *pref_dialog);
+static void gdict_pref_dialog_finalize (GObject *object);
 
 static void pref_dialog_add_db      (GDictPrefDialog *pref_dialog, 
                                      gchar *db, gchar *desc);
@@ -66,7 +50,6 @@ static void pref_status_cb          (dict_command_t *command,
 static void pref_data_cb            (dict_command_t *command, dict_res_t *res,
                                      gpointer data);
 
-static void phelp_cb		    (GtkDialog *dialog, gint response);
 static void response_cb		    (GtkDialog *dialog, gint response);
 static gboolean	set_server_cb 	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
 static gboolean set_port_cb	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
@@ -75,6 +58,21 @@ static void set_default_port        (GtkButton *button, gpointer data);
 static void smart_lookup_cb	    (GtkToggleButton *toggle, gpointer data);
 
 
+enum {
+    SOCKET_ERROR_SIGNAL,
+    LAST_SIGNAL
+};
+
+static gint gdict_pref_dialog_signals[LAST_SIGNAL] = { 0 };
+
+static GtkDialogClass *parent_class = NULL;
+
+GtkWidget *error_label1 = NULL;
+GtkWidget *error_label2 = NULL;
+GtkWidget *alignment1 = NULL;
+GtkWidget *alignment2 = NULL;
+
+
 /* gdict_pref_dialog_get_type
  *
  * Register the GDictPrefDialog type with Gtk's type system if necessary and
@@ -82,7 +80,8 @@ static void smart_lookup_cb	    (GtkToggleButton *toggle, gpointer data);
  */
 
 GType
-gdict_pref_dialog_get_type (void) {
+gdict_pref_dialog_get_type (void)
+{
     static GType gdict_pref_dialog_type = 0;
     
     g_type_init ();
@@ -109,16 +108,6 @@ gdict_pref_dialog_get_type (void) {
     return gdict_pref_dialog_type;
 }
 
-/* gdict_pref_dialog_init
- *
- * Initialises an instance of a GDictPrefDialog object
- */
-
-static void 
-gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
-
-}
-
 /* gdict_pref_dialog_class_init
  *
  * Initialises a structure describing the GDictPrefDialog class; sets
@@ -129,40 +118,40 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
 static void 
 gdict_pref_dialog_class_init (GDictPrefDialogClass *class) 
 {
-    GtkObjectClass *object_class;
-    
-    object_class = (GtkObjectClass *) class;
-    
-    gdict_pref_dialog_signals[APPLY_CHANGES_SIGNAL] =
-        gtk_signal_new ("apply_changes", GTK_RUN_FIRST,
-			GTK_CLASS_TYPE(object_class),
-                        GTK_SIGNAL_OFFSET (GDictPrefDialogClass,
-					   apply_changes),
-                        gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
+    GObjectClass *object_class;
     
+    object_class = G_OBJECT_CLASS (class);
+    parent_class = g_type_class_peek_parent (class);
+
     gdict_pref_dialog_signals[SOCKET_ERROR_SIGNAL] =
-        gtk_signal_new ("socket_error", GTK_RUN_FIRST,
-			GTK_CLASS_TYPE(object_class),
-                        GTK_SIGNAL_OFFSET (GDictPrefDialogClass, socket_error),
-                        g_cclosure_marshal_VOID__STRING, GTK_TYPE_NONE, 1,
-                        GTK_TYPE_STRING);
-#if 0    
-    gtk_object_class_add_signals (object_class, gdict_pref_dialog_signals,
-                                  LAST_SIGNAL);
-#endif    
-    object_class->destroy = (void (*) (GtkObject *)) gdict_pref_dialog_destroy;
-    
-    class->apply_changes = NULL;
+        g_signal_new ("socket_error",
+                      G_TYPE_FROM_CLASS (object_class),
+                      G_SIGNAL_RUN_FIRST,
+                      G_STRUCT_OFFSET (GDictPrefDialogClass, socket_error),
+                      NULL, NULL,
+                      g_cclosure_marshal_VOID__STRING,
+                      G_TYPE_NONE,
+                      1,
+                      G_TYPE_STRING);
+
+    object_class->finalize = gdict_pref_dialog_finalize;
 }
 
-static void
-create_dialog (GDictPrefDialog *pref_dialog)
+/* gdict_pref_dialog_init
+ *
+ * Initialises an instance of a GDictPrefDialog object
+ */
+
+static void 
+gdict_pref_dialog_init (GDictPrefDialog *pref_dialog)
 {
     GtkWidget *server_label, *port_label;
     GtkWidget *vbox;
     GtkWidget *button;    
     gchar *port_str;
     
+    pref_dialog->context = NULL;
+
     pref_dialog->database = gdict_pref.database;
     pref_dialog->dfl_strat = gdict_pref.dfl_strat;
     
@@ -212,7 +201,7 @@ create_dialog (GDictPrefDialog *pref_dialog)
     g_signal_connect (G_OBJECT (button), "clicked",
     		      G_CALLBACK (set_default_server), pref_dialog);
 
-    if( gail_loaded )
+    if (gail_loaded)
         add_atk_namedesc(GTK_WIDGET(button), NULL, _("Reset server to default"));
 
     if ( ! gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/server", NULL)) {
@@ -236,7 +225,7 @@ create_dialog (GDictPrefDialog *pref_dialog)
                       (GtkAttachOptions) (0), 0, 0);
     g_signal_connect (G_OBJECT (pref_dialog->port_entry), "focus_out_event",
     		      G_CALLBACK (set_port_cb), pref_dialog);
-                               
+
     button = gtk_button_new_with_mnemonic (_("Def_ault Port"));
     gtk_table_attach (pref_dialog->table, 
                       button, 2, 3, 1, 2,
@@ -244,9 +233,8 @@ create_dialog (GDictPrefDialog *pref_dialog)
                       (GtkAttachOptions) (0), 0, 0);
     g_signal_connect (G_OBJECT (button), "clicked",
     		      G_CALLBACK (set_default_port), pref_dialog);
-    
-    if( gail_loaded )
-    {
+
+    if (gail_loaded) {
         add_atk_namedesc(GTK_WIDGET(button), NULL, _("Reset port to default"));
         add_atk_namedesc(server_label, _("Server"), _("Server"));
         add_atk_namedesc( GTK_WIDGET (pref_dialog->server_entry), _("Server Entry"), _("Enter the Server Name"));
@@ -255,7 +243,6 @@ create_dialog (GDictPrefDialog *pref_dialog)
         add_atk_namedesc(port_label, _("Port"), _("Port"));
         add_atk_namedesc( GTK_WIDGET(pref_dialog->port_entry), _("Port Entry"), _("Enter the Port Number"));
         add_atk_relation( GTK_WIDGET(pref_dialog->port_entry), port_label, ATK_RELATION_LABELLED_BY);
-
     }
 
     if ( ! gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/port", NULL)) {
@@ -264,17 +251,17 @@ create_dialog (GDictPrefDialog *pref_dialog)
 	    gtk_widget_set_sensitive (button, FALSE);
     }
 
-    db_label = gtk_label_new_with_mnemonic (_("_Database:"));
-    gtk_label_set_justify (GTK_LABEL (db_label), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (db_label), 0, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, db_label, 0, 1, 3, 4);
+    pref_dialog->db_label = gtk_label_new_with_mnemonic (_("_Database:"));
+    gtk_label_set_justify (GTK_LABEL (pref_dialog->db_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (pref_dialog->db_label), 0, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, pref_dialog->db_label, 0, 1, 3, 4);
     pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->db_list));
     
-    strat_label = gtk_label_new_with_mnemonic (_("D_efault strategy:"));
-    gtk_label_set_justify (GTK_LABEL (strat_label), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (strat_label), 0, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, strat_label, 0, 1, 4, 5);
+    pref_dialog->strat_label = gtk_label_new_with_mnemonic (_("D_efault strategy:"));
+    gtk_label_set_justify (GTK_LABEL (pref_dialog->strat_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (pref_dialog->strat_label), 0, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, pref_dialog->strat_label, 0, 1, 4, 5);
     pref_dialog->strat_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->strat_list));
     
@@ -303,7 +290,25 @@ create_dialog (GDictPrefDialog *pref_dialog)
 	(GTK_TOGGLE_BUTTON (pref_dialog->smart_lookup_btn), gdict_pref.smart);
 
     gtk_widget_show_all (GTK_WIDGET (pref_dialog));
+}
 
+/* gdict_pref_dialog_finalize
+ *
+ * Finalize a GDictPrefDialog object
+ */
+
+static void
+gdict_pref_dialog_finalize (GObject *object)
+{
+    GDictPrefDialog *pref_dialog;
+
+    g_return_if_fail (GDICT_IS_PREF_DIALOG (object));
+
+    pref_dialog = GDICT_PREF_DIALOG (object);
+    dict_command_destroy (pref_dialog->get_db_cmd);
+    dict_command_destroy (pref_dialog->get_strat_cmd);
+
+    G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 /* gdict_pref_dialog_new
@@ -321,29 +326,15 @@ gdict_pref_dialog_new (dict_context_t *context)
      * to the console */
     if (context == NULL)
 	    return NULL;
-    
-    pref_dialog =
-	GDICT_PREF_DIALOG (gtk_type_new (gdict_pref_dialog_get_type ()));
+
+    pref_dialog = GDICT_PREF_DIALOG (g_object_new (GDICT_TYPE_PREF_DIALOG, NULL));
     pref_dialog->context = context;    
-    create_dialog (pref_dialog);
     pref_dialog_reset_db (pref_dialog);
     pref_dialog_reset_strat (pref_dialog);
-   
+
     return GTK_WIDGET (pref_dialog);
 }
 
-/* gdict_pref_dialog_destroy
- *
- * Destroys a pref_dialog dialog
- */
-
-void
-gdict_pref_dialog_destroy (GDictPrefDialog *pref_dialog) 
-{
-    dict_command_destroy (pref_dialog->get_db_cmd);
-    dict_command_destroy (pref_dialog->get_strat_cmd);
-}
-
 /* pref_set_db_cb
  *
  * Sets the current search strategy to the one indicated
@@ -353,11 +344,10 @@ static void
 pref_set_db_cb (GtkWidget *widget, gpointer data) 
 {
     GDictPrefDialog *pref_dialog;
-    
+
     pref_dialog = GDICT_PREF_DIALOG (data);
-    pref_dialog->database = 
-        gtk_object_get_data (GTK_OBJECT (widget), "db_name");
-        
+    pref_dialog->database = g_object_get_data (G_OBJECT (widget), "db_name");
+
     gconf_client_set_string (gdict_get_gconf_client (), "/apps/gnome-dictionary/database", pref_dialog->database, NULL);
 }
 
@@ -372,9 +362,8 @@ pref_set_strat_cb (GtkWidget *widget, gpointer data)
     GDictPrefDialog *pref_dialog;
     
     pref_dialog = GDICT_PREF_DIALOG (data);
-    pref_dialog->dfl_strat = 
-        gtk_object_get_data (GTK_OBJECT (widget), "strat_name");
-    
+    pref_dialog->dfl_strat = g_object_get_data (G_OBJECT (widget), "strat_name");
+
     gconf_client_set_string (gdict_get_gconf_client (), "/apps/gnome-dictionary/strategy", pref_dialog->dfl_strat, NULL);
 }
 
@@ -390,9 +379,9 @@ pref_dialog_add_db (GDictPrefDialog *pref_dialog, gchar *db,
     GtkWidget *menu_item;
     
     menu_item = gtk_menu_item_new_with_label (desc);
-    gtk_signal_connect (GTK_OBJECT (menu_item), "activate", 
-                        GTK_SIGNAL_FUNC (pref_set_db_cb), pref_dialog);
-    gtk_object_set_data (GTK_OBJECT (menu_item), "db_name", db);
+    g_signal_connect (G_OBJECT (menu_item), "activate", 
+                      G_CALLBACK (pref_set_db_cb), pref_dialog);
+    g_object_set_data (G_OBJECT (menu_item), "db_name", db);
     gtk_widget_show (menu_item);
     gtk_menu_append (pref_dialog->db_list, menu_item);
 
@@ -414,9 +403,9 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
     GtkWidget *menu_item;
     
     menu_item = gtk_menu_item_new_with_label (desc);
-    gtk_signal_connect (GTK_OBJECT (menu_item), "activate", 
-                        GTK_SIGNAL_FUNC (pref_set_strat_cb), pref_dialog);
-    gtk_object_set_data (GTK_OBJECT (menu_item), "strat_name", strat);
+    g_signal_connect (G_OBJECT (menu_item), "activate", 
+                      G_CALLBACK (pref_set_strat_cb), pref_dialog);
+    g_object_set_data (G_OBJECT (menu_item), "strat_name", strat);
     gtk_widget_show (menu_item);
     gtk_menu_append (pref_dialog->strat_list, menu_item);
     
@@ -434,8 +423,8 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
  */
 
 static void
-pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
-
+pref_dialog_reset_db (GDictPrefDialog *pref_dialog)
+{
     if (pref_dialog->get_db_cmd)
       dict_command_destroy (pref_dialog->get_db_cmd);
     
@@ -445,7 +434,7 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
         gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
         pref_dialog->db_sel = NULL;
     }
-  
+
     pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
     
     pref_dialog->get_db_cmd = dict_show_db_command_new ();
@@ -455,8 +444,7 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
     pref_dialog->get_db_cmd->user_data = pref_dialog;
     pref_dialog->database_idx = 0;
 
-    if ((alignment1) && (error_label1))
-    {
+    if ((alignment1) && (error_label1)) {
 	gtk_container_remove (GTK_CONTAINER (alignment1), error_label1);
 	gtk_widget_destroy (GTK_WIDGET (alignment1));
 	error_label1 = NULL;
@@ -464,7 +452,7 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
     }
     
     pref_dialog_add_db (pref_dialog, "*", _("Search all databases"));
- 
+
     if (dict_command_invoke (pref_dialog->get_db_cmd,
 			     pref_dialog->context) == -1)
     {
@@ -486,8 +474,8 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
  */
 
 static void
-pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
-
+pref_dialog_reset_strat (GDictPrefDialog *pref_dialog)
+{
     if (pref_dialog->get_strat_cmd)
 	dict_command_destroy (pref_dialog->get_strat_cmd);
     
@@ -507,8 +495,7 @@ pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
     pref_dialog->get_strat_cmd->user_data = pref_dialog;
     pref_dialog->dfl_strat_idx = 0;
 
-    if ((alignment2) && (error_label2))
-    {
+    if ((alignment2) && (error_label2)) {
 	gtk_container_remove (GTK_CONTAINER (alignment2), error_label2);
 	gtk_widget_destroy (GTK_WIDGET (alignment2));
 	error_label2 = NULL;
@@ -529,7 +516,6 @@ pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
     }
 }
 
-
 /* pref_error_cb
  *
  * Callback used when there is a socket error
@@ -542,7 +528,7 @@ pref_error_cb (dict_command_t *command, DictStatusCode code,
     GDictPrefDialog *pref_dialog;
     
     g_return_if_fail (data != NULL);
-    g_return_if_fail (IS_GDICT_PREF_DIALOG (data));
+    g_return_if_fail (GDICT_IS_PREF_DIALOG (data));
     
     pref_dialog = GDICT_PREF_DIALOG (data);
     
@@ -555,9 +541,9 @@ pref_error_cb (dict_command_t *command, DictStatusCode code,
 	gtk_widget_destroy (dialog);
     }
     else {
-        gtk_signal_emit (GTK_OBJECT (pref_dialog),
-                         gdict_pref_dialog_signals[SOCKET_ERROR_SIGNAL],
-                         message);
+        g_signal_emit (G_OBJECT (pref_dialog),
+                       gdict_pref_dialog_signals[SOCKET_ERROR_SIGNAL], 0,
+                       message);
     }
 }
 
@@ -568,11 +554,12 @@ pref_error_cb (dict_command_t *command, DictStatusCode code,
  */
 
 static void
-pref_data_cb (dict_command_t *command, dict_res_t *res, gpointer data) {
+pref_data_cb (dict_command_t *command, dict_res_t *res, gpointer data)
+{
     GDictPrefDialog *pref_dialog;
     
     g_return_if_fail (data != NULL);
-    g_return_if_fail (IS_GDICT_PREF_DIALOG (data));
+    g_return_if_fail (GDICT_IS_PREF_DIALOG (data));
     
     pref_dialog = GDICT_PREF_DIALOG (data);
     if (command->cmd == C_SHOW_DB)
@@ -598,7 +585,7 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
     gboolean writable;
     
     g_return_if_fail (data != NULL);
-    g_return_if_fail (IS_GDICT_PREF_DIALOG (data));
+    g_return_if_fail (GDICT_IS_PREF_DIALOG (data));
     
     pref_dialog = GDICT_PREF_DIALOG (data);
     
@@ -619,38 +606,36 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
                                    1, 3, row, row + 1);
         gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
         
-        if (command->cmd == C_SHOW_DB)
-        {
+        if (command->cmd == C_SHOW_DB) {
 	    pref_dialog->db_sel = option_menu;
-            gtk_label_set_mnemonic_widget (GTK_LABEL (db_label), GTK_WIDGET (pref_dialog->db_sel));
+            gtk_label_set_mnemonic_widget (GTK_LABEL (pref_dialog->db_label),
+                                           GTK_WIDGET (pref_dialog->db_sel));
 
-            if ( gail_loaded)
-            {
-                add_atk_namedesc(db_label, _("Database"), _("Database Name"));
-                add_atk_relation( GTK_WIDGET (option_menu), db_label, ATK_RELATION_LABELLED_BY);
+            if (gail_loaded) {
+                add_atk_namedesc(pref_dialog->db_label, _("Database"), _("Database Name"));
+                add_atk_relation( GTK_WIDGET (option_menu), pref_dialog->db_label, ATK_RELATION_LABELLED_BY);
 
             }
 
             writable = gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/database", NULL);
 
-	    gtk_widget_set_sensitive (db_label, writable);
+	    gtk_widget_set_sensitive (pref_dialog->db_label, writable);
 	    gtk_widget_set_sensitive (GTK_WIDGET (option_menu), writable);
         }
-        else if (command->cmd == C_SHOW_STRAT)
-        {
+        else if (command->cmd == C_SHOW_STRAT) {
 	    pref_dialog->strat_sel = option_menu;
-            gtk_label_set_mnemonic_widget (GTK_LABEL (strat_label), GTK_WIDGET (pref_dialog->strat_sel));
+            gtk_label_set_mnemonic_widget (GTK_LABEL (pref_dialog->strat_label),
+                                           GTK_WIDGET (pref_dialog->strat_sel));
 
-            if ( gail_loaded )
-            {
-                add_atk_namedesc(strat_label, _("Default Strategy"), _("Default Strategy"));
-                add_atk_relation( GTK_WIDGET (option_menu), strat_label, ATK_RELATION_LABELLED_BY);
+            if (gail_loaded) {
+                add_atk_namedesc(pref_dialog->strat_label, _("Default Strategy"), _("Default Strategy"));
+                add_atk_relation( GTK_WIDGET (option_menu), pref_dialog->strat_label, ATK_RELATION_LABELLED_BY);
 
             }
 
             writable = gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/strategy", NULL);
 
-	    gtk_widget_set_sensitive (strat_label, writable);
+	    gtk_widget_set_sensitive (pref_dialog->strat_label, writable);
 	    gtk_widget_set_sensitive (GTK_WIDGET (option_menu), writable);
         }
     }
@@ -659,26 +644,47 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
 static void 
 response_cb (GtkDialog *dialog, gint response)
 {
-    if(response == GTK_RESPONSE_HELP)
-    {
-       phelp_cb (dialog, response);
+    if (response == GTK_RESPONSE_HELP) {
+        GError *error = NULL;
+
+        gnome_help_display ("gnome-dictionary", "gdict-settings", &error);
+        if (error) {
+            GtkWidget *msg_dialog;
+
+            msg_dialog = gtk_message_dialog_new (GTK_WINDOW (dialog),
+                                                 GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                 GTK_MESSAGE_ERROR,
+                                                 GTK_BUTTONS_OK,
+                                                 _("There was an error displaying help: \n%s"),
+                                                 error->message);
+
+            g_signal_connect (G_OBJECT (msg_dialog), "response",
+                              G_CALLBACK (gtk_widget_destroy), NULL);
+
+            gtk_widget_show (msg_dialog);
+            g_error_free (error);
+       }
+
        return;
     }
+
     gtk_widget_hide (GTK_WIDGET (dialog));
 }
 
 static gboolean
 set_server_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
-    GDictPrefDialog *pref_dialog = data;
+    GDictPrefDialog *pref_dialog;
     gchar *server;
+
+    g_return_val_if_fail (GDICT_IS_PREF_DIALOG (data), FALSE);
+
+    pref_dialog = data;
     server = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->server_entry), 0, -1);
+    if (!server)
+        return FALSE;
 
-    g_return_val_if_fail (server != NULL, FALSE);
-
-    if ((server != NULL) && ((gdict_pref.server == NULL)
-			    || (strcmp (gdict_pref.server, server)))) {
-	
+    if ((gdict_pref.server == NULL) || (strcmp (gdict_pref.server, server))) {
 	if (gdict_pref.server)
 		g_free (gdict_pref.server);
         gdict_pref.server = g_strdup(server);
@@ -690,22 +696,22 @@ set_server_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
         gconf_client_set_string (gdict_get_gconf_client (), "/apps/gnome-dictionary/server", gdict_pref.server, NULL);
 
     }
-   
-    if (server)
-    	g_free (server);
-    	
+
+    g_free (server);
+
     return FALSE;
 }
 
-
 static gboolean 
 set_port_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
-    GDictPrefDialog *pref_dialog = data;
+    GDictPrefDialog *pref_dialog;
     gchar *port;
-    
+
+    g_return_val_if_fail (GDICT_IS_PREF_DIALOG (data), FALSE);
+
+    pref_dialog = data;
     port = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->port_entry), 0, -1);
-    
     if (gdict_pref.port != atoi (port)) {
     
         gdict_pref.port = atoi (port);
@@ -717,11 +723,9 @@ set_port_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
         pref_dialog_reset_strat (pref_dialog);
             
         gconf_client_set_int (gdict_get_gconf_client (), "/apps/gnome-dictionary/port", gdict_pref.port, NULL);
-       
     }
     
-    if (port)
-    	g_free (port);
+    g_free (port);
 
     return FALSE;
 }
@@ -729,24 +733,28 @@ set_port_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 static void
 set_default_server (GtkButton *button, gpointer data)
 {
-    GDictPrefDialog *pref_dialog = data;
-    
+    GDictPrefDialog *pref_dialog;
+
+    g_return_if_fail (GDICT_IS_PREF_DIALOG (data));
+
+    pref_dialog = data;
     gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry), DICT_DEFAULT_SERVER);
-    set_server_cb (GTK_WIDGET (pref_dialog->port_entry), NULL, data);
-    
+    set_server_cb (GTK_WIDGET (pref_dialog->port_entry), NULL, pref_dialog);
 }
 
 static void
 set_default_port (GtkButton *button, gpointer data)
 {
-    GDictPrefDialog *pref_dialog = data;
+    GDictPrefDialog *pref_dialog;
     gchar *port;
-    
+
+    g_return_if_fail (GDICT_IS_PREF_DIALOG (data));
+
+    pref_dialog = data;
     port = g_strdup_printf ("%d", DICT_DEFAULT_PORT);
     gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port);
     g_free (port);
-    set_port_cb (GTK_WIDGET (pref_dialog->port_entry), NULL, data);
-    
+    set_port_cb (GTK_WIDGET (pref_dialog->port_entry), NULL, pref_dialog);
 }    
 
 static void 
@@ -755,35 +763,7 @@ smart_lookup_cb	(GtkToggleButton *toggle, gpointer data)
     gboolean toggled;
     
     toggled = gtk_toggle_button_get_active (toggle);
-    if (toggled != gdict_pref.smart) {
+    if (toggled != gdict_pref.smart)
         gconf_client_set_bool (gdict_get_gconf_client (), "/apps/gnome-dictionary/smart", toggled, NULL);
-    }
-    
-
 }
 
-static void
-phelp_cb    (GtkDialog *dialog, gint response)
-{
-	GError *error = NULL;
-	gnome_help_display("gnome-dictionary","gdict-settings",&error);
-
-	if (error) {
-		GtkWidget *msg_dialog;
-
-		msg_dialog = gtk_message_dialog_new (GTK_WINDOW(dialog),
-						     GTK_DIALOG_DESTROY_WITH_PARENT,
-						     GTK_MESSAGE_ERROR,
-						     GTK_BUTTONS_OK,
-						     ("There was an error displaying help: \n%s"),
-						     error->message);
-
-		g_signal_connect (G_OBJECT (msg_dialog), "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-
-		gtk_window_set_resizable (GTK_WINDOW (msg_dialog), FALSE);
-		gtk_widget_show (msg_dialog);
-		g_error_free (error);
-	}
-}
