@@ -1,7 +1,7 @@
 #ifndef __GDICT_PREF_DIALOG_H_
 #define __GDICT_PREF_DIALOG_H_
 
-/* $Id: gdict-pref-dialog.h,v 1.3 2001/12/14 11:23:55 seth Exp $ */
+/* $Id: gdict-pref-dialog.h,v 1.4 2004/02/09 08:37:23 pborelli Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -11,7 +11,7 @@
  *  This code released under the GNU GPL.
  *  Read the file COPYING for more information.
  *
- *  GDict main window
+ *  GDict preferences window
  *
  */
 
@@ -24,9 +24,14 @@ extern "C" {
 #include "dict.h"
 #include "gdict-pref.h"
 
-#define GDICT_PREF_DIALOG(obj)         GTK_CHECK_CAST (obj, gdict_pref_dialog_get_type (), GDictPrefDialog)
-#define GDICT_PREF_DIALOG_CLASS(klass) GTK_CHECK_CLASS_CAST (klass, gdict_pref_dialog_get_type (), GDictPrefDialogClass)
-#define IS_GDICT_PREF_DIALOG(obj)      GTK_CHECK_TYPE (obj, gdict_pref_dialog_get_type ())
+
+#define GDICT_TYPE_PREF_DIALOG            (gdict_pref_dialog_get_type ())
+#define GDICT_PREF_DIALOG(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GDICT_TYPE_PREF_DIALOG, GDictPrefDialog))
+#define GDICT_PREF_DIALOG_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GDICT_TYPE_PREF_DIALOG, GDictPrefDialogClass))
+#define GDICT_IS_PREF_DIALOG(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GDICT_TYPE_PREF_DIALOG))
+#define GDICT_IS_PREF_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDICT_TYPE_PREF_DIALOG))
+#define GDICT_PREF_DIALOG_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GDICT_TYPE_PREF_DIALOG, GDictPrefDialogClass))
+
 
 typedef struct _GDictPrefDialog        GDictPrefDialog;
 typedef struct _GDictPrefDialogClass   GDictPrefDialogClass;
@@ -39,14 +44,13 @@ struct _GDictPrefDialog {
     GtkEntry         *port_entry;
     GtkCheckButton   *smart_lookup_btn;
     GtkCheckButton   *applet_handle_btn;
+    GtkWidget        *db_label;
+    GtkWidget        *strat_label;
     GtkOptionMenu    *db_sel;
     GtkMenu          *db_list;
     GtkOptionMenu    *strat_sel;
     GtkMenu          *strat_list;
-    
-    GnomeFontPicker  *font_pickers[NUM_TYPEFACES];
-    GnomeColorPicker *color_pickers[NUM_TYPEFACES];
-    
+
     dict_context_t   *context;
     dict_command_t   *get_db_cmd;
     dict_command_t   *get_strat_cmd;
@@ -60,7 +64,6 @@ struct _GDictPrefDialog {
 struct _GDictPrefDialogClass {
     GtkDialogClass parent_class;
     
-    void (*apply_changes) (GDictPrefDialog *);
     void (*socket_error)  (GDictPrefDialog *, gchar *);
 };
 
