@@ -59,7 +59,7 @@ static GFloppy *internal_floppy = NULL;
 static void
 print_status (void)
 {
-	gchar *msg = NULL;
+	char *msg = NULL;
 	gint val = 0;
 
 	val = CLAMP ( (gint) ((0.67 +  0.33*((gfloat)currently_testing)/num_blocks) * 100), 67, 100);
@@ -99,7 +99,7 @@ static long do_test (int dev, char * buffer, int try, unsigned long block_size,
 	if (got < 0)
 		got = 0;	
 	if (got & 511) {
-		gchar *msg;
+		char *msg;
 		msg = g_strdup_printf (_("Internal Error: Weird value (%ld) in do_test\n"), got);
 		fd_print (internal_floppy, MSG_MESSAGE, msg);
 		g_free (msg);
@@ -139,7 +139,7 @@ test_ro (int dev, unsigned long blocks_count,
 	num_blocks = blocks_count;
 	while (currently_testing < blocks_count)
 	{
-		gchar *msg;
+		char *msg;
 
 		print_status ();
 		if (currently_testing + try > blocks_count)
@@ -254,7 +254,7 @@ check_badblocks (GFloppy *floppy)
 	unsigned long blocks_count;
 	unsigned long from_count;
 	int dev;
-	gchar *msg;
+	char *msg;
 
 /*	while (!i)
 	;*/
