@@ -120,7 +120,7 @@ read_stdinput (gpointer data,
 	
 			if (floppy->nbadblocks > 0) {
 				dialog_type = GTK_MESSAGE_WARNING;
-				error_label = g_strdup_printf (_("The floppy has been formatted, but <b>%d bad blocks</b> (out of %d) have been found and marked."), floppy->nbadblocks, floppy->nblocks);
+				error_label = g_strdup_printf (ngettext ("The floppy has been formatted, but <b>%d bad block</b> (out of %d) has been found and marked.", "The floppy has been formatted, but <b>%d bad blocks</b> (out of %d) have been found and marked.", floppy->nbadblocks), floppy->nbadblocks, floppy->nblocks);
 			} else {
 				dialog_type = GTK_MESSAGE_INFO;
 				error_label = g_strdup (_("Floppy formatted successfully."));
