@@ -50,7 +50,7 @@ void
 click_stop_cb 			(GtkWidget 	*widget, 
 	       			 gpointer 	data);
 void
-click_check_button_cb		(GtkWidget	*widget, 
+click_expander_cb		(GtkWidget	*widget, 
 				 gpointer 	data);
 void   
 size_allocate_cb 		(GtkWidget 	*widget,
@@ -83,6 +83,9 @@ open_file_cb 			(GtkWidget 	*widget,
 void	
 open_folder_cb 			(GtkWidget 	*widget, 
 				 gpointer 	data);
+void	
+move_to_trash_cb		(GtkWidget 	*widget, 
+				 gpointer 	data);				 
 void  
 drag_begin_file_cb  		(GtkWidget          *widget,
 	      			 GdkDragContext     *context,
@@ -108,8 +111,8 @@ void
 show_file_selector_cb 		(GtkWidget 	*widget,
 				 gpointer 	data);
 void   	
-save_results_cb 		(GtkFileSelection   *selector, 
-				 gpointer 	    user_data, 
+save_results_cb 		(GtkWidget         *chooser, 
+				 gint	 	    response, 
 				 gpointer 	    data);
 void    
 save_session_cb 		(GnomeClient 	    *client, 
